==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/modules/calendar/language/en.php <==
<?php


$l["addressbook"]='Addressbook';
$l["appointments"]= 'Appointments';
$l["recurrence"]= 'Recurrence';
$l["options"]= 'Options';
$l["repeatForever"]= 'repeat forever';
$l["repeatEvery"]= 'Repeat every';
$l["repeatUntil"]= 'Repeat until';
$l["busy"]= 'Show as busy';
$l["allDay"]= 'Time is not applicable';
$l["navigation"]= 'Navigation';
$l["oneDay"]= '1 Day';
$l["fiveDays"]= '5 Days';
$l["sevenDays"]= '7 Days';
$l["month"]= 'Month';
$l["recurringEvent"]= 'Recurring event';
$l["deleteRecurringEvent"]= 'Do you want to delete a single instance or all instances of this recurring event?';
$l["singleOccurence"]= 'Single occurence';
$l["entireSeries"]= 'Entire series';
$l["calendar"]= 'Calendar';
$l["views"]= 'Views';
$l["administration"]= 'Administration';
$l["needsAction"]= 'Needs action';
$l["accepted"]= 'Accepted';
$l["declined"]= 'Declined';
$l["confirmed"]= 'Confirmed';
$l["tentative"]= 'Tentative';
$l["delegated"]= 'Delegated';
$l["noRecurrence"]= 'No recurrence';
$l["notRespondedYet"]= 'Not responded yet';
$l["days"]= 'days';
$l["weeks"]= 'weeks';
$l["monthsByDate"]= 'months by date';
$l["monthsByDay"]= 'months by day';
$l["years"]= 'years';
$l["atDays"]= 'At days';
$l["noReminder"]= 'No reminder';
$l["reminder"]='Reminder';
$l["participants"]= 'Participants';
$l["checkAvailability"]= 'Check availability';
$l["sendInvitation"]= 'Send invitation';
$l["emailSendingNotConfigured"]= 'E-mail sending is not configured.';
$l["privateEvent"]= 'Private';
$l["noInformationAvailable"]= 'No information available';
$l["noParticipantsToDisplay"]= 'No participants to display';
$l["previousDay"]= 'Previous day';
$l["nextDay"]= 'Next day';
$l["noAppointmentsToDisplay"]= 'No appointments to display';
$l["selectCalendar"]= 'Select calendar';
$l["selectCalendarForAppointment"]= 'Select the calendar to put this appointment in';
$l["closeWindow"]= 'The appointment has been accepted and scheduled. You can close this window.';
$l["list"]='List';
$l["editRecurringEvent"]='Do you want to edit this occurence or the entire series?';
$l["selectIcalendarFile"]='Select an icalendar (*.ics) file';
$l["eventDefaults"]='Defaults settings for appointments';
$l["importToCalendar"]='Add appointment directly to the calendars';
$l["default_calendar"]='Default calendar';
$l["resource_groups"]='Resource groups';
$l["resource_group"]='Resource group';
$l["resources"]='Resources';
$l["resource"]='Resource';
$l["calendar_group"]='Calendar group';
$l["admins"]='Administrators';
$l["no_group_selected"]='You have errors in your form. You need to select a group for this resource.';
$l["visibleCalendars"]='Visible calendars';
$l["visible"]='Visible';
$l["group"]='Group';
$l["no_status"]='New';
$l["no_custom_fields"]='There are no extra options available.';
$l["show_bdays"]='Show birthdays from addressbook';
$l["show_tasks"]='Show tasks from tasklists';
$l["myCalendar"]='My calendar';
$l["merge"]='Merge';
$l["ownColor"]= 'Give each calendar a unique color';
$l["ignoreConflictsTitle"]= 'Ignore conflict?';
$l["ignoreConflictsMsg"]= 'This event conflicts with another event in your calender. Save this event anyway?';
$l["resourceConflictTitle"]= 'Resource conflict';
$l["resourceConflictMsg"]= 'One or more resources in this event are already in use at the same time:</br>';
$l["view"]= 'View';
$l["calendarsPermissions"]='Calendars permissions';
$l["resourcesPermissions"]='Resources permissions';

$l["categories"]='Categories';
$l["category"]='Category';
$l["globalCategory"]='Global category';
$l["globalCategories"]='Global categories';
$l["selectCategory"]='Select category';
$l["duration"]='Timespan';
$l["move"]='Move';
$l["showInfo"]='Details';
$l["copyEvent"]='Copy event';
$l["moveEvent"]='Move event';
$l["eventInfo"]='Event details';
$l["isOrganizer"]='Organizer';
$l["sendInvitationInitial"]='Would you like to send meeting invitations to participants?';
$l["sendInvitationUpdate"]='Would you like to send updated meeting information to participants?';
$l["sendCancellation"]='Would you like to send all the participants a cancelation notice?';
$l["forthcomingAppointments"]='Forthcoming appointments';
$l["quarterShort"]= 'Q';
$l["globalsettings_templatelabel"]= 'Template';
$l["globalsettings_allchangelabel"]= 'Rename all existing';
$l["globalsettings_renameall"]= 'Are you sure you want to rename all default user calendars?';
$l["publishICS"]='Publish iCalendar file of last month and future events. Caution! The calendar will be readable to everyone.';
$l["addTimeRegistration"]='Import into timeregistration';
$l["showNotBusy"]='Don\'t show new reservations as busy';
$l["sendEmailParticipants"]= 'Create email for participants';
$l['name'] = 'Calendar';
$l['description'] = 'Calendar module; Every user can add, edit or delete appointments Also appointments from other users can be viewed and if necessary it can be changed.';
$l['groupView'] = 'Group view';
$l['event']='Event';
$l['startsAt']='Starts at';
$l['endsAt']='Ends at';
$l['exceptionNoCalendarID'] = 'FATAL: No calendar ID!';
$l['appointment'] = 'Appointment';
$l['allTogether'] = 'All together';
$l['invited']='You are invited for the following event';
$l['acccept_question']='Do you accept this event?';
$l['accept']='Accept';
$l['decline']='Decline';
$l['bad_event']='The event doesn\'t exist anymore';
$l['subject']='Subject';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION'] = 'Needs action';
$l['statuses']['ACCEPTED'] = 'Accepted';
$l['statuses']['DECLINED'] = 'Declined';
$l['statuses']['TENTATIVE'] = 'Tentative';
$l['statuses']['DELEGATED'] = 'Delegated';
$l['statuses']['COMPLETED'] = 'Completed';
$l['statuses']['IN-PROCESS'] = 'In process';
$l['statuses']['CONFIRMED'] = 'Confirmed';
$l['accept_mail_subject'] = 'Invitation for \'%s\' accepted';
$l['accept_mail_body'] = '%s has accepted your invitation for:';
$l['decline_mail_subject'] = 'Invitation for \'%s\' declined';
$l['decline_mail_body'] = '%s has declined your invitation for:';
$l['location']='Location';
$l['and']='and';
$l['repeats'] = 'Repeats every %s';
$l['repeats_at'] = 'Repeats every %s at %s';//eg. Repeats every month at the first monday;
$l['repeats_at_not_every'] = 'Repeats every %s %s at %s';//eg. Repeats every 2 weeks at monday;
$l['repeats_not_every'] = 'Repeats every %s %s';
$l['until']='until'; ;
$l['not_invited']='You were not invited to this event. You might need to login as a different user.';
$l['accept_title']='Accepted';
$l['accept_confirm']='The owner will be notified that you accepted the event';
$l['decline_title']='Declined';
$l['decline_confirm']='The owner will be notified that you declined the event';
$l['cumulative']='Invalid recurrence rule. The next occurence may not start before the previous has ended.';
$l['already_accepted']='You already accepted this event.';
$l['private']='Private';
$l['import_success']='%s events were imported';
$l['printTimeFormat']='From %s till %s';
$l['printLocationFormat']=' at location "%s"';
$l['printPage']='Page %s of %s';
$l['printList']='List of appointments';
$l['printAllDaySingle']='All day';
$l['printAllDayMultiple']='All day from %s till %s';
$l['calendars']='Calendars';
$l['open_resource']='Open booking';
$l['resource_mail_subject']='Resource \'%s\' booked for \'%s\' on \'%s\'';//%s is resource name, %s is event name, %s is start date;
$l['resource_mail_body']='%s has made a booking for the resource \'%s\'. You are the maintainer of this resource. Please open the booking to decline or approve it.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['resource_modified_mail_subject']='Resource \'%s\' booking for \'%s\' on \'%s\' modified';//%s is resource name, %s is event name, %s is start date;
$l['resource_modified_mail_body']='%s has modified a booking for the resource \'%s\'. You are the maintainer of this resource. Please open the booking to decline or approve it.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Your booking for \'%s\' on \'%s\' in status \'%s\' is modified';//is resource name, %s is event name, %s is start date;
$l['your_resource_modified_mail_body']='%s has modified your booking for the resource \'%s\'.';
$l['your_resource_accepted_mail_subject']='Your booking for \'%s\' on \'%s\' is accepted';//%s is resource name, %s is start date;
$l['your_resource_accepted_mail_body']='%s has accepted your booking for the resource \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']='Your booking for \'%s\' on \'%s\' is declined';//%s is resource name, %s is start date;
$l['your_resource_declined_mail_body']='%s has declined your booking for the resource \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Birthday: {NAME}';
$l['birthday_desc']='{NAME} has turned {AGE} today';
$l['unauthorized_participants_write']='You have insufficient permissions to schedule appointments for the following users:<br /><br />{NAMES}<br /><br />You might want to send them an invitation so they can accept and schedule it.';
$l['noCalSelected'] = 'No calendars have been selected for this overview. Select at least one calendar in Administration.';
$l['month_times'][1]='the first';
$l['month_times'][2]='the second';
$l['month_times'][3]='the third';
$l['month_times'][4]='the fourth';
$l['month_times'][5]='the fifth';
$l['rightClickToCopy']='Right click to copy link location';
$l['invitation']='Invitation';
$l['invitation_update']='Updated invitation';
$l['cancellation']='Cancellation';
$l['cancelMessage']='The following event you have been invited for has been cancelled.';
$l['non_selected'] = 'in non-selected calendar';
$l['linkIfCalendarNotSupported']='Only use the links below if your mail client does not support calendaring functions.';
$l['eventAccepted']='You have accepted the event.';
$l['eventScheduledIn']='The event has been scheduled in your calendar named %s with status %s.';
$l['eventDeclined']="You have declined the event.";
$l['eventUpdatedIn']='The event in calendar %s has been updated with status %s';

$l['updateReponses'][1]='%s has accepted the event %s';
$l['updateReponses'][2]='%s has declined the event %s';
$l['updateReponses'][3]='%s has marked the event %s as tentative';

$l['directUrl']='Direct URL';
$l['cantRemoveOrganizer']="You can't remove the organizer";
$l['calendarColor']='Calendar color';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/calendar/language/en.php <==
<?php


$l["addressbook"]='Addressbook';
$l["appointments"]= 'Appointments';
$l["recurrence"]= 'Recurrence';
$l["options"]= 'Options';
$l["repeatForever"]= 'repeat forever';
$l["repeatEvery"]= 'Repeat every';
$l["repeatUntil"]= 'Repeat until';
$l["busy"]= 'Show as busy';
$l["allDay"]= 'Time is not applicable';
$l["navigation"]= 'Navigation';
$l["oneDay"]= '1 Day';
$l["fiveDays"]= '5 Days';
$l["sevenDays"]= '7 Days';
$l["month"]= 'Month';
$l["recurringEvent"]= 'Recurring event';
$l["deleteRecurringEvent"]= 'Do you want to delete a single instance or all instances of this recurring event?';
$l["singleOccurence"]= 'Single occurence';
$l["entireSeries"]= 'Entire series';
$l["calendar"]= 'Calendar';
$l["views"]= 'Views';
$l["administration"]= 'Administration';
$l["needsAction"]= 'Needs action';
$l["accepted"]= 'Accepted';
$l["declined"]= 'Declined';
$l["confirmed"]= 'Confirmed';
$l["tentative"]= 'Tentative';
$l["delegated"]= 'Delegated';
$l["noRecurrence"]= 'No recurrence';
$l["notRespondedYet"]= 'Not responded yet';
$l["days"]= 'days';
$l["weeks"]= 'weeks';
$l["monthsByDate"]= 'months by date';
$l["monthsByDay"]= 'months by day';
$l["years"]= 'years';
$l["months"]= 'months';
$l["month"]= 'month';
$l["atDays"]= 'At days';
$l["noReminder"]= 'No reminder';
$l["reminder"]='Reminder';
$l["participants"]= 'Participants';
$l["checkAvailability"]= 'Check availability';
$l["sendInvitation"]= 'Send invitation';
$l["emailSendingNotConfigured"]= 'E-mail sending is not configured.';
$l["privateEvent"]= 'Private';
$l["noInformationAvailable"]= 'No information available';
$l["noParticipantsToDisplay"]= 'No participants to display';
$l["previousDay"]= 'Previous day';
$l["nextDay"]= 'Next day';
$l["noAppointmentsToDisplay"]= 'No appointments to display';
$l["selectCalendar"]= 'Select calendar';
$l["selectCalendarForAppointment"]= 'Select the calendar to put this appointment in';
$l["closeWindow"]= 'The appointment has been accepted and scheduled. You can close this window.';
$l["list"]='List';
$l["editRecurringEvent"]='Do you want to edit this occurence or the entire series?';
$l["selectIcalendarFile"]='Select an icalendar (*.ics) file';
$l["eventDefaults"]='Defaults settings for appointments';
$l["importToCalendar"]='Add appointment directly to the calendars';
$l["default_calendar"]='Default calendar';
$l["resource_groups"]='Resource groups';
$l["resource_group"]='Resource group';
$l["resources"]='Resources';
$l["resource"]='Resource';
$l["calendar_group"]='Calendar group';
$l["admins"]='Administrators';
$l["no_group_selected"]='You have errors in your form. You need to select a group for this resource.';
$l["visibleCalendars"]='Visible calendars';
$l["visible"]='Visible';
$l["group"]='Group';
$l["no_status"]='New';
$l["no_custom_fields"]='There are no extra options available.';
$l["show_bdays"]='Show birthdays from addressbook';
$l["show_tasks"]='Show tasks from tasklists';
$l["myCalendar"]='My calendar';
$l["merge"]='Merge';
$l["ownColor"]= 'Give each calendar a unique color';
$l["ignoreConflictsTitle"]= 'Ignore conflict?';
$l["ignoreConflictsMsg"]= 'This event conflicts with another event in your calender. Save this event anyway?';
$l["resourceConflictTitle"]= 'Resource conflict';
$l["resourceConflictMsg"]= 'One or more resources in this event are already in use at the same time:</br>';
$l["view"]= 'View';
$l["calendarsPermissions"]='Calendars permissions';
$l["resourcesPermissions"]='Resources permissions';

$l["categories"]='Categories';
$l["category"]='Category';
$l["globalCategory"]='Global category';
$l["globalCategories"]='Global categories';
$l["selectCategory"]='Select category';
$l["duration"]='Timespan';
$l["move"]='Move';
$l["showInfo"]='Details';
$l["copyEvent"]='Copy event';
$l["moveEvent"]='Move event';
$l["eventInfo"]='Event details';
$l["isOrganizer"]='Organizer';
$l["sendInvitationInitial"]='Would you like to send meeting invitations to participants?';
$l["sendInvitationUpdate"]='Would you like to send updated meeting information to participants?';
$l["sendCancellation"]='Would you like to send all the participants a cancelation notice?';
$l["forthcomingAppointments"]='Forthcoming appointments';
$l["quarterShort"]= 'Q';
$l["globalsettings_templatelabel"]= 'Template';
$l["globalsettings_allchangelabel"]= 'Rename all existing';
$l["globalsettings_renameall"]= 'Are you sure you want to rename all default user calendars?';
$l["publishICS"]='Publish iCalendar file of last month and future events. Caution! The calendar will be readable to everyone.';
$l["addTimeRegistration"]='Import into timeregistration';
$l["showNotBusy"]='Don\'t show new reservations as busy';
$l["sendEmailParticipants"]= 'Create email for participants';
$l['name'] = 'Calendar';
$l['description'] = 'Calendar module; Every user can add, edit or delete appointments Also appointments from other users can be viewed and if necessary it can be changed.';
$l['groupView'] = 'Group view';
$l['event']='Event';
$l['startsAt']='Starts at';
$l['endsAt']='Ends at';
$l['exceptionNoCalendarID'] = 'FATAL: No calendar ID!';
$l['appointment'] = 'Appointment';
$l['allTogether'] = 'All together';
$l['invited']='You are invited for the following event';
$l['acccept_question']='Do you accept this event?';
$l['accept']='Accept';
$l['decline']='Decline';
$l['bad_event']='The event doesn\'t exist anymore';
$l['subject']='Subject';
$l['status']='Status';
$l['statuses']['NEEDS-ACTION'] = 'Needs action';
$l['statuses']['ACCEPTED'] = 'Accepted';
$l['statuses']['DECLINED'] = 'Declined';
$l['statuses']['TENTATIVE'] = 'Tentative';
$l['statuses']['DELEGATED'] = 'Delegated';
$l['statuses']['COMPLETED'] = 'Completed';
$l['statuses']['IN-PROCESS'] = 'In process';
$l['statuses']['CONFIRMED'] = 'Confirmed';
$l['statuses']['CANCELLED'] = 'Cancelled';
$l['accept_mail_subject'] = 'Invitation for \'%s\' accepted';
$l['accept_mail_body'] = '%s has accepted your invitation for:';
$l['decline_mail_subject'] = 'Invitation for \'%s\' declined';
$l['decline_mail_body'] = '%s has declined your invitation for:';
$l['location']='Location';

$l['not_invited']='You were not invited to this event. You might need to login as a different user.';
$l['accept_title']='Accepted';
$l['accept_confirm']='The owner will be notified that you accepted the event';
$l['decline_title']='Declined';
$l['decline_confirm']='The owner will be notified that you declined the event';
$l['cumulative']='Invalid recurrence rule. The next occurence may not start before the previous has ended.';
$l['already_accepted']='You already accepted this event.';
$l['private']='Private';
$l['import_success']='%s events were imported';
$l['printTimeFormat']='From %s till %s';
$l['printLocationFormat']=' at location "%s"';
$l['printPage']='Page %s of %s';
$l['printList']='List of appointments';
$l['printAllDaySingle']='All day';
$l['printAllDayMultiple']='All day from %s till %s';
$l['calendars']='Calendars';
$l['open_resource']='Open booking';
$l['resource_mail_subject']='Resource \'%s\' booked for \'%s\' on \'%s\'';//%s is resource name, %s is event name, %s is start date;
$l['resource_mail_body']='%s has made a booking for the resource \'%s\'. You are the maintainer of this resource. Please open the booking to decline or approve it.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['resource_modified_mail_subject']='Resource \'%s\' booking for \'%s\' on \'%s\' modified';//%s is resource name, %s is event name, %s is start date;
$l['resource_modified_mail_body']='%s has modified a booking for the resource \'%s\'. You are the maintainer of this resource. Please open the booking to decline or approve it.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_modified_mail_subject']='Your booking for \'%s\' on \'%s\' in status \'%s\' is modified';//is resource name, %s is event name, %s is start date;
$l['your_resource_modified_mail_body']='%s has modified your booking for the resource \'%s\'.';
$l['your_resource_accepted_mail_subject']='Your booking for \'%s\' on \'%s\' is accepted';//%s is resource name, %s is start date;
$l['your_resource_accepted_mail_body']='%s has accepted your booking for the resource \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['your_resource_declined_mail_subject']='Your booking for \'%s\' on \'%s\' is declined';//%s is resource name, %s is start date;
$l['your_resource_declined_mail_body']='%s has declined your booking for the resource \'%s\'.'; //First %s is the name of the person who created the event. Second is the calendar name;
$l['birthday_name']='Birthday: {NAME}';
$l['birthday_desc']='{NAME} has turned {AGE} today';
$l['unauthorized_participants_write']='You have insufficient permissions to schedule appointments for the following users:<br /><br />{NAMES}<br /><br />You might want to send them an invitation so they can accept and schedule it.';
$l['noCalSelected'] = 'No calendars have been selected for this overview. Select at least one calendar in Administration.';

$l['rightClickToCopy']='Right click to copy link location';
$l['invitation']='Invitation';
$l['invitation_update']='Updated invitation';
$l['cancellation']='Cancellation';
$l['cancelMessage']='The following event has been cancelled by the organizer';
$l['non_selected'] = 'in non-selected calendar';
$l['linkIfCalendarNotSupported']='Only use the links below if your mail client does not support calendaring functions.';
$l['eventAccepted']='You have accepted the event.';
$l['eventScheduledIn']='The event has been scheduled in your calendar named %s with status %s.';
$l['eventDeclined']="You have declined the event.";
$l['eventUpdatedIn']='The event in calendar %s has been updated with status %s';

$l['updateReponses']["ACCEPTED"]='%s has accepted the event %s';
$l['updateReponses']["DECLINED"]='%s has declined the event %s';
$l['updateReponses']["TENTATIVE"]='%s has marked the event %s as tentative';

$l['directUrl']='Direct URL';

$l['errorOrganizerOnly'] = 'You are not authorised to edit this event because you are not the organizer.';
$l['errorOrganizerOnlyTitle'] = 'You are not the organizer';
$l['cantRemoveOrganizer']="You can't remove the organizer";
$l['calendarColor']='Calendar color';
$l['eventDeleted']="The event was deleted from your calendar";

$l['attendance']='Attendance';
$l['organizer']='Organizer';
$l['notifyOrganizer']="Notify the organizer by e-mail about my decision";

$l['iWillAttend']="I will attend";
$l['iMightAttend']="I might attend";
$l['iWillNotAttend']="I will not attend";
$l['iWillDecideLater']="I haven't decided yet";

$l['eventUpdated']="The following event has been updated by the organizer";

$l['notifyCancelParticipants']='Would you like to send a cancellation notice to the participants?';
$l['notifyCancelOrganizer']='Would you like to notify the organizer that you will not attend by e-mail?';
$l['notifyParticipants']='Notify participants?';
$l['sendNotificationTitle']='Send notification?';
$l['sendNotification']='Would you like to notify the participants by e-mail?';

$l['openCalendar']='Open calendar';
$l['createPermission']="Create permission";
